@@ -37,7 +37,7 @@ extern "C" {
 
 #define SCMP_VER_MAJOR		2
 #define SCMP_VER_MINOR		3
-#define SCMP_VER_MICRO		2
+#define SCMP_VER_MICRO		3
 
 struct scmp_version {
 	unsigned int major;
@@ -1619,6 +1619,25 @@ int seccomp_export_bpf(const scmp_filter_ctx ctx, int fd);
 #define __NR_pkey_free		__PNR_pkey_free
 #endif /* __NR_pkey_free */
 
+#define __PNR_get_tls		-10204
+#ifndef __NR_get_tls
+#ifdef __ARM_NR_get_tls
+#define __NR_get_tls		__ARM_NR_get_tls
+#else
+#define __NR_get_tls		__PNR_get_tls
+#endif
+#endif /* __NR_get_tls */
+
+#define __PNR_s390_guarded_storage	-10205
+#ifndef __NR_s390_guarded_storage
+#define __NR_s390_guarded_storage	__PNR_s390_guarded_storage
+#endif /* __NR_s390_guarded_storage */
+
+#define __PNR_s390_sthyi	-10206
+#ifndef __NR_s390_sthyi
+#define __NR_s390_sthyi		__PNR_s390_sthyi
+#endif /* __NR_s390_sthyi */
+
 #ifdef __cplusplus
 }
 #endif
